timerelationtools.timespan_2_overlaps_start_of_timespan_1
=========================================================

.. autofunction:: abjad.tools.timerelationtools.timespan_2_overlaps_start_of_timespan_1.timespan_2_overlaps_start_of_timespan_1
   :noindex:
